@@ -69,6 +69,8 @@
 #include "hexchat-plugin.h"
 #undef _POSIX_C_SOURCE	/* Avoid warnings from /usr/include/features.h */
 #undef _XOPEN_SOURCE
+#undef HAVE_MEMRCHR /* Avoid redefinition in Python.h */
+#undef HAVE_STRINGS_H
 #include <Python.h>
 #include <structmember.h>
 #include <pythread.h>
@@ -568,7 +570,7 @@ Callback_Server(char *word[], char *word_eol[], hexchat_event_attrs *attrs, void
 	PyObject *retobj;
 	PyObject *word_list, *word_eol_list;
 	PyObject *attributes;
-	int ret = 0;
+	int ret = HEXCHAT_EAT_NONE;
 	PyObject *plugin;
 
 	plugin = hook->plugin;
@@ -577,13 +579,13 @@ Callback_Server(char *word[], char *word_eol[], hexchat_event_attrs *attrs, void
 	word_list = Util_BuildList(word);
 	if (word_list == NULL) {
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 	word_eol_list = Util_BuildList(word_eol);
 	if (word_eol_list == NULL) {
 		Py_DECREF(word_list);
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 
 	attributes = Attribute_New(attrs);
@@ -619,7 +621,7 @@ Callback_Command(char *word[], char *word_eol[], void *userdata)
 	Hook *hook = (Hook *) userdata;
 	PyObject *retobj;
 	PyObject *word_list, *word_eol_list;
-	int ret = 0;
+	int ret = HEXCHAT_EAT_NONE;
 	PyObject *plugin;
 
 	plugin = hook->plugin;
@@ -628,13 +630,13 @@ Callback_Command(char *word[], char *word_eol[], void *userdata)
 	word_list = Util_BuildList(word);
 	if (word_list == NULL) {
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 	word_eol_list = Util_BuildList(word_eol);
 	if (word_eol_list == NULL) {
 		Py_DECREF(word_list);
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 
 	retobj = PyObject_CallFunction(hook->callback, "(OOO)", word_list,
@@ -665,7 +667,7 @@ Callback_Print_Attrs(char *word[], hexchat_event_attrs *attrs, void *userdata)
 	PyObject *word_list;
 	PyObject *word_eol_list;
 	PyObject *attributes;
-	int ret = 0;
+	int ret = HEXCHAT_EAT_NONE;
 	PyObject *plugin;
 
 	plugin = hook->plugin;
@@ -674,13 +676,13 @@ Callback_Print_Attrs(char *word[], hexchat_event_attrs *attrs, void *userdata)
 	word_list = Util_BuildList(word);
 	if (word_list == NULL) {
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 	word_eol_list = Util_BuildEOLList(word);
 	if (word_eol_list == NULL) {
 		Py_DECREF(word_list);
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 
 	attributes = Attribute_New(attrs);
@@ -714,7 +716,7 @@ Callback_Print(char *word[], void *userdata)
 	PyObject *retobj;
 	PyObject *word_list;
 	PyObject *word_eol_list;
-	int ret = 0;
+	int ret = HEXCHAT_EAT_NONE;
 	PyObject *plugin;
 
 	plugin = hook->plugin;
@@ -723,13 +725,13 @@ Callback_Print(char *word[], void *userdata)
 	word_list = Util_BuildList(word);
 	if (word_list == NULL) {
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 	word_eol_list = Util_BuildEOLList(word);
 	if (word_eol_list == NULL) {
 		Py_DECREF(word_list);
 		END_PLUGIN(plugin);
-		return 0;
+		return HEXCHAT_EAT_NONE;
 	}
 
 	retobj = PyObject_CallFunction(hook->callback, "(OOO)", word_list,
@@ -1530,7 +1532,7 @@ Plugin_New(char *filename, PyObject *xcoobj)
 	if (filename) {
 #ifdef WIN32
 		char *file;
-		if (!g_file_get_contents_utf8(filename, &file, NULL, NULL)) {
+		if (!g_file_get_contents(filename, &file, NULL, NULL)) {
 			hexchat_printf(ph, "Can't open file %s: %s\n",
 				     filename, strerror(errno));
 			goto error;
@@ -1849,7 +1851,7 @@ Module_hexchat_pluginpref_get(PyObject *self, PyObject *args)
 			BEGIN_XCHAT_CALLS(NONE);
 			retint = hexchat_pluginpref_get_int(prefph, var);
 			END_XCHAT_CALLS();
-			if ((retint == 0) && (strcmp(retstr, "0") != 0))
+			if ((retint == -1) && (strcmp(retstr, "-1") != 0))
 				ret = PyUnicode_FromString(retstr);
 			else
 				ret = PyLong_FromLong(retint);
@@ -2508,9 +2510,9 @@ IInterp_Cmd(char *word[], char *word_eol[], void *userdata)
 	if (channel && channel[0] == '>' && strcmp(channel, ">>python<<") == 0) {
 		hexchat_printf(ph, ">>> %s\n", word_eol[1]);
 		IInterp_Exec(word_eol[1]);
-		return 1;
+		return HEXCHAT_EAT_HEXCHAT;
 	}
-	return 0;
+	return HEXCHAT_EAT_NONE;
 }
 
 
