@@ -94,7 +94,8 @@ static const struct defaultserver def[] =
 
 	{"BetaChat", 0, 0, 0, LOGIN_SASL},
 	{0,			"irc.betachat.net"},
-
+	{"BuddyIM", 0, 0, 0, LOGIN_SASL, 0, TRUE},
+	{0,			"irc.buddy.im"},
 	{"Canternet", 0, 0, 0, LOGIN_SASL, 0, TRUE},
 	{0,			"irc.canternet.org"},
 
@@ -256,8 +257,7 @@ static const struct defaultserver def[] =
 	/* Self signed */
 	{0,			"irc.oceanius.com"},
 
-	{"OFTC",	0},
-	/* Uncommon CA? */
+	{"OFTC", 0, 0, 0, 0, 0, TRUE},
 	{0,			"irc.oftc.net"},
 
 	{"OtherNet",	0},
@@ -1006,6 +1006,8 @@ servlist_load (void)
 	while (fgets (buf, sizeof (buf) - 2, fp))
 	{
 		len = strlen (buf);
+		if (!len)
+			continue;
 		buf[len] = 0;
 		buf[len-1] = 0;	/* remove the trailing \n */
 		if (net)
